人工智能 (豆瓣)
Description: 人工智能电影简介和剧情介绍,人工智能影评、图片、预告片、影讯、论坛、在线购票
Keywords: 人工智能,Artificial Intelligence: AI,人工智能影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.211豆瓣电影Top250

# 人工智能 Artificial Intelligence: AI (2001)

导演: 史蒂文·斯皮尔伯格
编剧: 布莱恩·奥尔迪斯 / 伊恩·沃森 / 史蒂文·斯皮尔伯格
主演: 海利·乔·奥斯蒙 / 弗兰西丝·奥康纳 / 山姆·洛巴兹 / 杰克·托马斯 / 裘德·洛 / 威廉·赫特 / 梁振邦 / 克拉克·格雷格 / 凯文·苏斯曼 / 汤姆·加洛普 / 尤金·奥斯门特 / 艾普尔·格雷斯 / 马特·温斯顿 / 萨布丽娜·格德维奇 / 西奥·格林利
类型: 剧情 / 科幻
官方网站: http://aimovie.warnerbros.com/
制片国家/地区: 美国 / 英国
语言: 英语
上映日期: 2001-06-29(美国)
片长: 146分钟
又名: AI人工智慧
IMDb: tt0212720
豆瓣评分
引用
8.7
422280人评价
5星
48.5%
4星
38.6%
3星
11.5%
2星
1.1%
1星
0.3%
好于 98% 科幻片
好于 97% 剧情片
想看 看过
评价:
推荐

## 人工智能的剧情简介 · · · · · ·

21世纪中期，由于温室效应，南北极冰川融化，地球上很多城市被淹没。此时，人类科技已经高度发达，人工智能机器人就是人类发明出来用以应对恶劣自然环境的科技手段之一，而且，机器人制造技术已经高度发达，先进的机器人不但拥有可以乱真的人类外表，还能感知自身的存在。
莫妮卡的儿子马丁重病住院，生命危在旦夕，为了缓解伤痛的心情，她领养了机器人小孩大卫（海利•乔•奥斯蒙特 饰），大卫的生存使命就是爱她。马丁苏醒，恢复健康，回到了家里，一系列的事情使大卫“失宠”，最后被莫妮卡抛弃。
在躲过机器屠宰场的残酷追杀后，大卫在机器情人乔（裘德•洛 饰）的帮助下，开始寻找自己的生存价值：渴望变成真正的小孩，重新回到莫妮卡妈妈的身边。谁也不知道他能否完成自己的心愿，脱胎换骨成为真正的人，等待他们的只是凶吉难料的旅程…… ©豆瓣

## 人工智能的演职员 · · · · · · ( 全部 158 )

- 史蒂文·斯皮尔伯格 导演
- 海利·乔·奥斯蒙 演员
- 弗兰西丝·奥康纳 演员
- 山姆·洛巴兹 演员
- 杰克·托马斯 演员
- 裘德·洛 演员

## 人工智能的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片801 · 添加 )

## 人工智能的获奖情况 · · · · · · ( 全部 )

- 第74届奥斯卡金像奖
- 最佳视觉效果(提名)
- 斯坦·温斯顿 / 丹尼斯·穆伦 / 斯科特·法勒 / 迈克尔·兰蒂里

- 第59届金球奖
- 电影类 最佳导演(提名)
- 史蒂文·斯皮尔伯格

- 第25届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  E.T.外星人

  这个男人来自地球

  黑客帝国3：矩阵革命

  2001太空漫游

  第九区

  阿凡达

  终结者2：审判日

  我，机器人

  回到未来

  源代码

我要写短评

## 人工智能的短评 · · · · · · ( 全部 92316 条 )

热门 / 最新 / 好友

### 3364 有用 裸踝 看过 2008-12-07 11:43:14

我要一只泰迪熊和一个舞男乔。

### 2006 有用 战国客 看过 2008-06-05 01:31:54

很奇怪，看斯皮尔伯格的电影，即使有些场景拍摄得十分感人，但总是不能让我从心里感动，可能是觉得太商业了，太刻意了？

### 1369 有用 亚比煞 看过 2010-12-16 16:37:49

有些电影，是你在当下觉得了了，而今后偶然回想起某个片段，才会为它痛哭一场的，比如，戴维从残破的大厦上落入水中的那一幕。my love is real，but I‘m not。

### 6222 有用 它它爱妮鸡 看过 2007-11-03 16:29:17

那只熊在自己缝自己！！

### 3313 有用 Su 看过 2012-04-25 12:15:54

如果不能爱我很久，为什么要启动我爱的程序？

> 更多短评 92316条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 人工智能的影评 · · · · · · ( 全部 1518 条 )

热门 / 最新 / 好友
七先生™ 2010-07-04 23:06:39

## 卑微的泰迪熊

不知道大家是否都把注意力给了小男孩大卫。 我在这里只想写点话给卑微的泰迪。 泰迪也是人工智能，但他不如大卫高级，也不具有人的形态。可既然是智能（具有部分智慧），它就会希望获得爱。 泰迪教大卫写字，写的内容是：“马丁和大卫是妈妈的儿子，但泰迪不是...” 妈妈的头发... (展开)
7976 85 451回应 收起
张天翼 2008-03-25 18:46:28

## 人类啊，你们不配得到永恒的感情

这篇影评可能有剧透

这小男孩，金发，温柔的眼睛，第一个出厂的机器人小孩。只要启动程序，他就会对作为启动者的父母爱而不渝。一对亲生子重病被冰冻的伤心父母得到了他：David。(David是我最喜爱的英文名) 母亲Monica在几天的犹豫之后，一个阳光淡淡的早晨，启动了David的程序。她抚着David颈后的... (展开)
2100 168 277回应 收起
席德 2006-11-03 13:29:35

## 一切假设均基于我邪恶的心灵

这篇影评可能有剧透

Ⅰ/ "LOVE" 也许在我眼里“love”并没有传说中的高贵。站在医学的角度，可以扯上一堆荷尔蒙、多巴胺之类的玩意——实在难以理解，所以我站在一个普通人的角度：所谓“love”不过是人类使自己“感觉良好”的手段之一。恋人爱彼此的音容相貌，亲人爱共同的血缘基因，朋友爱相处时... (展开)
1144 188 281回应 收起
豆友1120428 2007-08-26 23:48:07

## 当程序是爱——再看《人工智能》

他的程序是爱。当爱成为他生存的唯一理由，这个孩子无法不穷其毕生去寻找、去等待，千年万载，轮回往复。 　　 　　 “让妈妈爱我”——这样一个简单到极点的愿望，在孩子蔚蓝的眼睛里闪烁。 　　 　　 　　 我又怎么能忍住自己的泪水，为了他，为了他从出生就注定无法抹... (展开)
644 87 163回应 收起
defy 2013-05-16 14:15:23

## 既然这一切只是设定 而并不是自主选择

这篇影评可能有剧透

刚开头真的很像恐怖片啊，大卫突然冒出来不仅把女主吓了一跳把我也吓了一跳。我一直到大卫被抛弃之前还觉得他肯定会突然崩坏然后杀了马丁杀了亨利。 …… 咳咳切入正题。 莫妮卡真的对大卫好吗？我觉得不是，她看他的眼神总是带着防备和惧怕，仅有的呵护也是把他当做了马丁... (展开)
537 54 101回应 收起
cub18 2005-07-11 20:18:58

## 无主题漫游

感谢库布里克与斯皮尔伯格联手为我们献上了这部《AI》，我相信它将经受时间的考验，成为一部经典。如果这是部库氏单独完成的作品，那么它必将会狞厉而更具穿透力，但斯皮尔伯格为它披上了层温情的外纱，将《AI》制成了块酒心巧克力，醇美而意味深长。作品对人类、宇宙的终级思... (展开)
410 35 72回应 收起
方慧 2010-12-11 06:03:42

## 最孤独的是泰迪熊

电影开头有伏笔：“人可以让机器人对人付出百分百的爱，可是人对机器人的爱不应该负责任吗？”没有人回答。 另外最孤独的应该是那只泰迪熊吧。 他教David写字，写的却是：“亨利是妈妈的儿子，大卫是妈妈的儿子，泰迪不是。” 它没事就拿个针在身上缝缝补补。 David和妈妈一起... (展开)
393 11 21回应 收起
ealin 2006-03-09 15:47:23

## 上穷碧落下黄泉，两处茫茫皆不见——关于电影《人工智能》

“David is 11 years old. He weighs 60 pounds. He is 4 feet, 6 inches tall. He has brown hair. His love is real. But he is not.” 为《AI》写点什么，很早以前就想过，不是要突增悲哀，只是有些东西，看过便不能忘记。一如“他的爱是真的，然而，他不是”。 ... (展开)
234 13 39回应 收起
似此星辰 2013-07-19 00:23:48

## 只是因为短评写不下但我又想吐槽

看得太痛苦了，而且绝对不是因为被戳中泪点。 究竟什么材料能在海面下两千年还一点不被腐蚀；究竟为什么整个海洋都结冰了，但海底有个只在雕塑上结了一层冰壳的空荡大厅；究竟为什么外星人非要有头有躯干有四肢甚至还是五趾——以上这些都已经不是槽点了， 我已经可以理解了，... (展开)
245 67 76回应 收起
亚比煞 2010-12-16 20:07:03

## 对你驯养过的一切，负责到底

耶和华神用地上的尘土造人，将生气吹在他鼻孔里。 他就成了有灵的活人，名叫亚当。 《旧约·创世纪》第二章七节 每次读到这里，我都想象那个画面 我始终不是太明白什么叫做“成了有灵的活人” 这件事听起来似乎就像输入了某种程序，然后启动，亚当就活了。 这就是人类最初被... (展开)
194 9 17回应 收起

> 更多影评 1518篇

添加新讨论

## 讨论区 · · · · · ·

Ai与人类 爱与延续 | 来自边缘行者 |  | 2022-11-14 13:33:18
david发现有许多和自己相同外形的机器人的那段是不... | 来自MONTY围脖 |  | 2022-11-10 11:38:20
我就是不理解，为什么能感动哭了? | 来自幼稚园小哥 | 22 回应 | 2022-11-06 16:58:01
IMDB7.2分 | 来自Youngsheldon |  | 2022-11-02 17:03:59
如果2011年内真的做出来“泰迪”你们会买么？ | 来自深浅传媒 | 49 回应 | 2022-10-22 22:46:42

> 去这部影片的讨论区（全部303条）

## 关于《人工智能》的问题 · · · · · · ( 全部19个 )

- 机器情人约会的第二个女子是怎么死掉的？ 3人回答
- 这孩子是不是因为想和妈妈度过唯一属于他们的一天而变成了人类最后死去了？ 12人回答

> 全部19个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 北京电影学院硕士要看的100部电影 (悲`馨)
- 那些和谐的腐剧，腐动画，腐电影们。 (墨 尘)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- Cloris雷菁
  刚刚 看过
- 77
  4分钟前 看过
- kidding
  6分钟前 想看

619132人看过 / 260297人想看

订阅人工智能的评论:
feed: rss 2.0